

relNetworkBCalc <- function(data=NULL, gLabelID = "GeneName",sLabelID="Classification", samples=NULL,
type="Rpearson", bRep=1000, geneA=NULL, geneB=NULL, result=NULL, genes=NULL, ...) {

    ## Doing a simple test...
    if(is.null(data))
        stop("The data MUST be specified!!!")
    
    if(!(type %in% c("Rpearson", "pearson", "kendall", "spearman", "MI")))
        stop("Parameter 'type' must be 'Rpearson', 'pearson', 'kendall',
        'spearman' or 'MI'.")
		
	
	if(is.null(genes))
		stop("You must enter a valid list of genes")

	if(is.null(result)){
	
		corObj <- matrix(,length(unique(genes)),length(unique(genes)),TRUE)
		rownames(corObj) <- unique(genes)
		colnames(corObj) <- unique(genes)
					
		pValue <- matrix(,length(unique(genes)),length(unique(genes)),TRUE)
		rownames(pValue) <- unique(genes)
		colnames(pValue) <- unique(genes)
		
		bootM <- matrix(,length(unique(genes)),length(unique(genes)),TRUE)
		rownames(bootM) <- unique(genes)
		colnames(bootM) <- unique(genes)
		
		## Picking R and packages version information
		tmp <- sessionInfo()
		vInfo <- list()
		vInfo$R.version <- tmp$R.version$version.string
		vInfo$BasePacks <- tmp$basePkgs
		tmp1 <- NULL
		for (i in 1:length(tmp$otherPkgs))
			tmp1 <- c(tmp1, paste(tmp$otherPkgs[[i]]$Package, "version",
			tmp$otherPkgs[[i]]$Version))

		vInfo$AddPacks <- tmp1

		## Defining the object to return
		result <- new("maigesRelNetB", Corr=corObj, Pval=pValue,
		maxB=bootM, Date=date(), type=paste(samples, collapse=", "),
		Slabel=sLabelID, V.info=vInfo)
	}
	
	allSamples <- getLabels(data, sLabelID)
	allGenes <- getLabels(data, gLabelID, FALSE)
		
	## Constructing the table to be used
    table <- calcW(data)
	
	    
    ##  Getting the first 2 sample types to use in case of NULL samples parameter
    if(is.null(samples))
        samples <- unique(allSamples)[1]
    
    
    ## Finding indexes of the samples specified and respective lengths
    idxTmp <- allSamples %in% samples
    table <- table[, idxTmp]
    sTypes <- allSamples[idxTmp]
	
	 

	
	## Construct the table with 2 genes each time
	if(!is.null(geneA) & !is.null(geneB)){
		tableTmp <- NULL
		
		idx <- allGenes %in% geneA
		if(sum(idx) > 1)
			tableTmp <- rbind(tableTmp, apply(table[idx, ], 2, mean,
			na.rm=TRUE))
		
		else
			tableTmp <- rbind(tableTmp, table[idx, ])
			
		idx <- allGenes %in% geneB			       
		if(sum(idx) > 1)
			tableTmp <- rbind(tableTmp, apply(table[idx, ], 2, mean,
			na.rm=TRUE))?index
		
		else
			tableTmp <- rbind(tableTmp, table[idx, ])
			
		##Aplicar regra de filtro em tableTmp
		##filter(tableTmp)

		
		## Naming tableTmp
		id <- genes %in% c(geneA,geneB)
		rownames(tableTmp) <- unique(genes[id])
		colnames(tableTmp) <- sTypes
			
		## Finding indexes of the samples specified and respective lengths
		sample1 <- which(sTypes %in% samples)
		##n1 <- length(sample1)
		
		corObjTmp <- corCalc(type, tableTmp, sample1)
		pValueTmp <- pValCalc(type , tableTmp, sample1, bRep)
		bootMTmp <- bootMCalc(type, tableTmp, sample1, bRep)
		
		
		
		result@Corr[geneA,geneA] <-  corObjTmp[1,1]
		result@Corr[geneA,geneB] <-  corObjTmp[1,2]
		result@Corr[geneB,geneA] <-  corObjTmp[2,1]
		result@Corr[geneB,geneB] <-  corObjTmp[2,2]
		
		result@Pval[geneA,geneA] <-  pValueTmp[1,1]
		result@Pval[geneA,geneB] <-  pValueTmp[1,2]
		result@Pval[geneB,geneA] <-  pValueTmp[2,1]
		result@Pval[geneB,geneB] <-  pValueTmp[2,2]
		
		result@maxB[geneA,geneA] <-  bootMTmp[1,1]
		result@maxB[geneA,geneB] <-  bootMTmp[1,2]
		result@maxB[geneB,geneA] <-  bootMTmp[2,1]
		result@maxB[geneB,geneB] <-  bootMTmp[2,2]
					
	}
					
		
		
		
		result@W <- tableTmp		
		return(result)
}	