relNetworkMWrite <- function(data=NULL, gLabelID = "GeneName",sLabelID="Classification", samples=NULL,
type="Rpearson", bRep=1000, geneA=NULL, geneB=NULL, result=NULL, genes=NULL, tableTmp=NULL, ...) {
	
	
	 if(!(type %in% c("Rpearson", "pearson", "kendall", "spearman", "MI")))
        stop("Parameter 'type' must be 'Rpearson', 'pearson', 'kendall',
        'spearman' or 'MI'.")
		
	
	allSamples <- getLabels(data, sLabelID)

	## Getting the first 2 sample types to use in case of NULL samples
    ## parameter
    if(is.null(samples)) {
        samples <- list(unique(allSamples)[1], unique(allSamples)[2])
        names(samples) <- unique(allSamples)[1:2]
    }
	
	if(is.null(result)){
	
		corObj1 <- matrix(,length(unique(genes)),length(unique(genes)),TRUE)
		rownames(corObj1) <- unique(genes)
		colnames(corObj1) <- unique(genes)
					
		corObj2 <- matrix(,length(unique(genes)),length(unique(genes)),TRUE)
		rownames(corObj2) <- unique(genes)
		colnames(corObj2) <- unique(genes)
		
		difPvalue <- matrix(,length(unique(genes)),length(unique(genes)),TRUE)
		rownames(difPvalue) <- unique(genes)
		colnames(difPvalue) <- unique(genes)
		
		## Picking R and packages version information
		tmp <- sessionInfo()
		vInfo <- list()
		vInfo$R.version <- tmp$R.version$version.string
		vInfo$BasePacks <- tmp$basePkgs
		tmp1 <- NULL
		for (i in 1:length(tmp$otherPkgs))
			tmp1 <- c(tmp1, paste(tmp$otherPkgs[[i]]$Package, "version",
			tmp$otherPkgs[[i]]$Version))

		vInfo$AddPacks <- tmp1
		
	    ## Defining the object to return
	    result <- new("maigesRelNetM", Corr1=corObj1, Corr2=corObj2,
	    DifP=difPvalue, Date=date(), types=names(samples), Slabel=sLabelID,
	    V.info=vInfo)
	
	}
	

	## Finding indexes of the samples specified and respective lengths
    sample1 <- which(colnames(tableTmp) %in% samples[[1]])
    sample2 <- which(colnames(tableTmp) %in% samples[[2]])
    n1 <- length(sample1)
    n2 <- length(sample2)

	
	## Calculating the correlation coefficients
    if(type == "Rpearson") {
        corObj1 <- robustCorr(tableTmp[, sample1], ...)[[1]]
        corObj2 <- robustCorr(tableTmp[, sample2], ...)[[1]]
        ## Calculating the p-values of the differences
        difPvalue <- compCorr((n1-1), corObj1, (n2-1), corObj2)[[2]]
    }
    ##else if(type == "MI") {
    ##    corObj1 <- MI(tableTmp[, sample1], ...)
    ##    corObj2 <- MI(tableTmp[, sample2], ...)
    ## Calculating the p-values of the differences
    ##    difPvalue <- compCorr(n1, corObj1, n2, corObj2)[[2]]
    ##}
    else {
        corObj1 <- cor(t(tableTmp[, sample1]), method=type, ...)
        corObj2 <- cor(t(tableTmp[, sample2]), method=type, ...)
        ## Calculating the p-values of the differences
        difPvalue <- compCorr(n1, corObj1, n2, corObj2)[[2]]
    }
	
	
	
	corObjTmp <- corCalc(type, tableTmp, sample1)
	pValueTmp <- pValCalc(type , tableTmp, sample1, bRep)
	bootMTmp <- bootMCalc(type, tableTmp, sample1, bRep)
	
	
	if(is.null(geneA) & is.null(geneB)){
		result@Corr1 = corObj1
		result@Corr2 = corObj2
		result@DifP = difPvalue
		}
	else{
		result@Corr1[geneA,geneA] <-  corObj1[1,1]
		result@Corr1[geneA,geneB] <-  corObj1[1,2]
		result@Corr1[geneB,geneA] <-  corObj1[2,1]
		result@Corr1[geneB,geneB] <-  corObj1[2,2]
		
		result@Corr2[geneA,geneA] <-  corObj2[1,1]
		result@Corr2[geneA,geneB] <-  corObj2[1,2]
		result@Corr2[geneB,geneA] <-  corObj2[2,1]
		result@Corr2[geneB,geneB] <-  corObj2[2,2]
		
		result@DifP[geneA,geneA] <-  difPvalue[1,1]
		result@DifP[geneA,geneB] <-  difPvalue[1,2]
		result@DifP[geneB,geneA] <-  difPvalue[2,1]
		result@DifP[geneB,geneB] <-  difPvalue[2,2]
	}
	if (dim(result@W)[1] == 0)
		result@W <- tableTmp
	else{
		while (dim(tableTmp)[2] != dim(result@W)[2])
			if(dim(tableTmp)[2] > dim(result@W)[2])
				result@W <- cbind(result@W,NA)
			else
				tableTmp <- cbind(tableTmp,NA)
		

	result@W <- rbind(result@W, tableTmp)	
	}
	return(result)

}