library(maigesPack)
data(gastro)

source("relNetworkBNew.R")
source("relNetworkMNew.R")
source("relNetworkBuildTable.R")
source("relNetworkBWrite.R")
source("relNetworkMWrite.R")
source("getGenes.R")
source("corCalc.R")
source("pValCalc.R")
source("bootMCalc.R")
source("simpleNaFilter.R")
source("removeNaNames.R")

gastro = addGeneGrps(gastro, folder = "geneGrps", ext = "txt")
gastro = addPaths(gastro, folder = "geneNets", ext = "tgf")
gastro.raw = createMaigesRaw(gastro, greenDataField = "Ch1.Mean", greenBackDataField = "Ch1.B.Mean", redDataField = "Ch2.Mean", redBackDataField = "Ch2.B.Mean", flagDataField = "Flags", gLabelGrp = "GeneName", gLabelPath = "GeneName")
gastro.raw2 = selSpots(gastro.raw, sigNoise = 1, rmFlag = NULL, gLabelsID = "Name", remove = list(c("BLANK", "DAP", "LYS", "PHE", "Q_GENE", "THR", "TRP")))
gastro.norm = normLoc(gastro.raw2, span = 0.4, method = "loess")
gastro.summ = summarizeReplicates(gastro.norm, gLabelID = "GeneName", sLabelID = "Sample", funcS = "mean", funcG = "median", keepEmpty = FALSE, rmBad = FALSE)

gastroB.net = relNetworkB(gastro.summ, sLabelID = "Tissue", samples = "Neso", geneGrp = 1)
gastroBNew1.net = testeParB(gastro.summ, sLabelID = "Tissue", samples = "Neso", geneGrp = 1)
gastroBNew2.net = testeTodosB(gastro.summ, sLabelID = "Tissue", samples = "Neso", geneGrp = 1)
gastroBNew3.net = testeTodosParB(gastro.summ, sLabelID = "Tissue", samples = "Neso", geneGrp = 1)

print(gastroB.net@W)
print(gastroBNew1.net@W)
print(gastroBNew2.net@W)

print(gastroB.net@Corr)
print(gastroBNew1.net@Corr)
print(gastroBNew2.net@Corr)

print(gastroB.net@Pval)
print(gastroBNew1.net@Pval)
print(gastroBNew2.net@Pval)

print(gastroB.net@maxB)
print(gastroBNew1.net@maxB)
print(gastroBNew2.net@maxB)

gastroM.net = relNetworkM(gastro.summ, sLabelID="Tissue",samples = list(Neso="Neso", Aeso="Aeso"), geneGrp=11, type="Rpearson")
gastroMNew1.net = testeParM(gastro.summ, sLabelID="Tissue",samples = list(Neso="Neso", Aeso="Aeso"), geneGrp=11, type="Rpearson")
gastroMNew2.net = testeTodosM(gastro.summ, sLabelID="Tissue",samples = list(Neso="Neso", Aeso="Aeso"), geneGrp=11, type="Rpearson")

print(gastroM.net@W)
print(gastroMNew1.net@W)
print(gastroMNew2.net@W)

print(gastroM.net@Corr1)
print(gastroMNew1.net@Corr1)
print(gastroMNew2.net@Corr1)

print(gastroM.net@Corr2)
print(gastroMNew1.net@Corr2)
print(gastroMNew2.net@Corr2)

print(gastroM.net@DifP)
print(gastroMNew1.net@DifP)
print(gastroMNew2.net@DifP)





